<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}

class Vayne_Visual_Composer{

    public $category;

    public static $instance = null;

    public static function get_instance()
    {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct(){

        $this->category = esc_html_x( 'La Studio', 'admin-view', 'vayne');

        if(!class_exists('Vc_Manager')) return false;

        add_action( 'vc_before_init', array( $this, 'vcBeforeInit') );
        add_action( 'vc_after_init', array( $this, 'vcAfterInit') );
        add_filter( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG , array( $this, 'customFilterTags' ), 10, 3 );
        add_filter('vc_tta_container_classes', array( $this, 'modifyTtaTabsClasses'), 10, 2 );

    }

    public function vcBeforeInit(){
        vc_automapper()->setDisabled( true );
        vc_manager()->disableUpdater( true );
        vc_manager()->setIsAsTheme( true );
        if(class_exists( 'WooCommerce' )){
            remove_action( 'wp_enqueue_scripts', 'vc_woocommerce_add_to_cart_script' );
        }
        add_filter('vc_map_get_param_defaults', array( $this, 'modifyCssAnimationValue' ), 10, 2);
    }

    public function vcAfterInit(){
        $this->overrideVcSection();
        //$this->overrideMessage();
        $this->overrideProgressBar();
        $this->overridePieChart();
        $this->overrideTtaAccordion();
        $this->overrideTtaTabs();
        $this->overrideTtaTour();
        $this->overrideTtaSection();

        if( function_exists('vc_set_default_editor_post_types') ){
            $list = array(
                'page',
                'post',
                'la_block',
                'la_portfolio'
            );
            vc_set_default_editor_post_types( $list );
        }
    }

    public function modifyCssAnimationValue($value, $param){
        if( 'css_animation' ==  $param['param_name'] && 'none' == $value){
            $value = '';
        }
        return $value;
    }

    public function customFilterTags($css_classes, $shortcode_name, $atts){
        if ( $shortcode_name == 'vc_progress_bar' ){
            if( isset($atts['display_type']) ){
                $css_classes .= ' vc_progress_bar_' . esc_attr($atts['display_type']);
            }
        }
        if ( $shortcode_name == 'vc_tta_tabs' || $shortcode_name == 'vc_tta_accordion' || $shortcode_name == 'vc_tta_tour' ){
            if( isset($atts['style']) && strpos($atts['style'], 'la-') !== false ){
                $css_classes = preg_replace('/ vc_tta-(o|shape|spacing|gap|color)[0-9a-zA-Z\_\-]+/','',$css_classes);
                if($shortcode_name == 'vc_tta_tabs'){
                    $css_classes .= ' vc_tta-o-no-fill';
                    $css_classes = str_replace('vc_tta-style-','tabs-',$css_classes);
                    $css_classes = str_replace('vc_general ','',$css_classes);
                }
                if($shortcode_name == 'vc_tta_tour'){
                    $css_classes = str_replace('vc_tta-style-','tour-',$css_classes);
                    $css_classes = str_replace('vc_general ','',$css_classes);
                }
            }
        }
        if($shortcode_name == 'vc_btn'){
            if(!empty($atts['style']) && in_array($atts['style'], array('modern', 'outline', 'custom', 'outline-custom'))){
                if( false !== strpos( $css_classes, 'vc_btn3-container')){
                    $css_classes .= ' la-vc-btn';
                }
            }
        }

        if ( $shortcode_name == 'vc_row' ) {
            $css_classes .= ' la_fp_slide la_fp_child_section';
        }

        return $css_classes;
    }

    public function overrideMessage(){
        $shortcode_name = 'vc_message';

        $shortcode_object = vc_get_shortcode($shortcode_name);
        $shortcode_params = $shortcode_object['params'];
        
        $icon_type = self::getParamIndex($shortcode_params,'icon_type');
        
        if($icon_type !== -1){
            $shortcode_params[$icon_type]['value'][esc_html_x( 'None', 'admin-view', 'vayne' )] = 'none';
        }

        vc_map_update($shortcode_name , array(
            'category' => $this->category,
            'params' => $shortcode_params
        ));
    }

    public function overrideProgressBar(){
        vc_map_update( 'vc_progress_bar', array(
            'category' => $this->category,
            'params' => array(
                array(
                    'type' => 'param_group',
                    'heading' => esc_html__( 'Values', 'vayne' ),
                    'param_name' => 'values',
                    'description' => esc_html__( 'Enter values for graph - value, title and color.', 'vayne' ),
                    'value' => urlencode( json_encode( array(
                        array(
                            'label' => esc_html__( 'Development', 'vayne' ),
                            'value' => '90',
                        ),
                        array(
                            'label' => esc_html__( 'Design', 'vayne' ),
                            'value' => '80',
                        ),
                        array(
                            'label' => esc_html__( 'Marketing', 'vayne' ),
                            'value' => '70',
                        ),
                    ) ) ),
                    'params' => array(
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__( 'Label', 'vayne' ),
                            'param_name' => 'label',
                            'description' => esc_html__( 'Enter text used as title of bar.', 'vayne' ),
                            'admin_label' => true,
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__( 'Value', 'vayne' ),
                            'param_name' => 'value',
                            'description' => esc_html__( 'Enter value of bar.', 'vayne' ),
                            'admin_label' => true,
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__( 'Color', 'vayne' ),
                            'param_name' => 'color',
                            'value' => array(
                                    esc_html__( 'Default', 'vayne' ) => '',
                                ) + array(
                                    esc_html__( 'Classic Grey', 'vayne' ) => 'bar_grey',
                                    esc_html__( 'Classic Blue', 'vayne' ) => 'bar_blue',
                                    esc_html__( 'Classic Turquoise', 'vayne' ) => 'bar_turquoise',
                                    esc_html__( 'Classic Green', 'vayne' ) => 'bar_green',
                                    esc_html__( 'Classic Orange', 'vayne' ) => 'bar_orange',
                                    esc_html__( 'Classic Red', 'vayne' ) => 'bar_red',
                                    esc_html__( 'Classic Black', 'vayne' ) => 'bar_black',
                                ) + getVcShared( 'colors-dashed' ) + array(
                                    esc_html__( 'Gradient', 'vayne' ) => 'gradient',
                                    esc_html__( 'Custom Color', 'vayne' ) => 'custom'
                                ),
                            'description' => esc_html__( 'Select single bar background color.', 'vayne' ),
                            'admin_label' => true,
                            'param_holder_class' => 'vc_colored-dropdown',
                        ),
                        array(
                            'type' => 'colorpicker',
                            'heading' => esc_html__( 'Custom color', 'vayne' ),
                            'param_name' => 'customcolor',
                            'description' => esc_html__( 'Select custom single bar background color.', 'vayne' ),
                            'dependency' => array(
                                'element' => 'color',
                                'value' => array( 'custom' ),
                            ),
                        ),
                        array(
                            'type' => 'colorpicker',
                            'heading' => esc_html__( 'Custom text color', 'vayne' ),
                            'param_name' => 'customtxtcolor',
                            'description' => esc_html__( 'Select custom single bar text color.', 'vayne' ),
                            'dependency' => array(
                                'element' => 'color',
                                'value' => array( 'custom' ),
                            )
                        ),
                    ),
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__( 'Units', 'vayne' ),
                    'param_name' => 'units',
                    'description' => esc_html__( 'Enter measurement units (Example: %, px, points, etc. Note: graph value and units will be appended to graph title).', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__( 'Color', 'vayne' ),
                    'param_name' => 'bgcolor',
                    'value' => array(
                            esc_html__( 'Classic Grey', 'vayne' ) => 'bar_grey',
                            esc_html__( 'Classic Blue', 'vayne' ) => 'bar_blue',
                            esc_html__( 'Classic Turquoise', 'vayne' ) => 'bar_turquoise',
                            esc_html__( 'Classic Green', 'vayne' ) => 'bar_green',
                            esc_html__( 'Classic Orange', 'vayne' ) => 'bar_orange',
                            esc_html__( 'Classic Red', 'vayne' ) => 'bar_red',
                            esc_html__( 'Classic Black', 'vayne' ) => 'bar_black',
                        ) + getVcShared( 'colors-dashed' ) + array(
                            esc_html__( 'Gradient', 'vayne' ) => 'gradient',
                            esc_html__( 'Custom Color', 'vayne' ) => 'custom'
                        ),
                    'description' => esc_html__( 'Select bar background color.', 'vayne' ),
                    'admin_label' => true,
                    'param_holder_class' => 'vc_colored-dropdown',
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Bar custom background color', 'vayne' ),
                    'param_name' => 'custombgcolor',
                    'description' => esc_html__( 'Select custom background color for bars.', 'vayne' ),
                    'dependency' => array(
                        'element' => 'bgcolor',
                        'value' => array( 'custom' ),
                    ),
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Bar custom text color', 'vayne' ),
                    'param_name' => 'customtxtcolor',
                    'description' => esc_html__( 'Select custom text color for bars.', 'vayne' ),
                    'dependency' => array(
                        'element' => 'bgcolor',
                        'value' => array( 'custom' ),
                    ),
                ),
                array(
                    'type' => 'checkbox',
                    'heading' => esc_html__( 'Options', 'vayne' ),
                    'param_name' => 'options',
                    'value' => array(
                        esc_html__( 'Add stripes', 'vayne' ) => 'striped',
                        esc_html__( 'Add animation (Note: visible only with striped bar).', 'vayne' ) => 'animated',
                    ),
                ),
                vc_map_add_css_animation(),
                array(
                    'type' => 'el_id',
                    'heading' => esc_html__( 'Element ID', 'vayne' ),
                    'param_name' => 'el_id'
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__( 'Extra class name', 'vayne' ),
                    'param_name' => 'el_class',
                    'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'vayne' ),
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'vayne' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'vayne' ),
                ),
            )
        ));
    }

    public function overridePieChart(){
        $shortcode_tag = 'vc_pie';
        $shortcode_object = vc_get_shortcode($shortcode_tag);
        $shortcode_params = $shortcode_object['params'];

        $shortcode_params = array(
            array(
                'type' => 'dropdown',
                'param_name' => 'style',
                'value' => array(
                    esc_html_x( 'Style 01', 'admin-view', 'vayne' ) => '1',
                    esc_html_x( 'Style 02', 'admin-view', 'vayne' ) => '2',
                ),
                'default'   => '1',
                'heading' => esc_html_x( 'Style', 'admin-view', 'vayne' ),
                'description' => esc_html_x( 'Select display style.', 'admin-view', 'vayne' )
            )
        ) + $shortcode_params ;

        vc_map_update( $shortcode_tag , array(
            'category' => $this->category,
            'params'   => $shortcode_params
        ));
    }

    public function overrideTtaAccordion(){
        vc_map_update('vc_tta_accordion' , array(
            'category' => $this->category,
            'params' => array(
                array(
                    'type' => 'dropdown',
                    'param_name' => 'style',
                    'value' => array(
                        esc_html_x( 'Vayne 01', 'admin-view', 'vayne' ) => 'la-1',
                        esc_html_x( 'Vayne 02', 'admin-view', 'vayne' ) => 'la-2',
                        esc_html_x( 'Vayne 03', 'admin-view', 'vayne' ) => 'la-3',
                        esc_html_x( 'Classic', 'admin-view', 'vayne' ) => 'classic',
                        esc_html_x( 'Modern', 'admin-view', 'vayne' ) => 'modern',
                        esc_html_x( 'Flat', 'admin-view', 'vayne' ) => 'flat',
                        esc_html_x( 'Outline', 'admin-view', 'vayne' ) => 'outline',
                    ),
                    'heading' => esc_html_x( 'Style', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion display style.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'shape',
                    'value' => array(
                        esc_html_x( 'Rounded', 'admin-view', 'vayne' ) => 'rounded',
                        esc_html_x( 'Square', 'admin-view', 'vayne' ) => 'square',
                        esc_html_x( 'Round', 'admin-view', 'vayne' ) => 'round',
                    ),
                    'heading' => esc_html_x( 'Shape', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion shape.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'color',
                    'value' => getVcShared( 'colors-dashed' ),
                    'std' => 'grey',
                    'heading' => esc_html_x( 'Color', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion color.', 'admin-view', 'vayne' ),
                    'param_holder_class' => 'vc_colored-dropdown',
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'checkbox',
                    'param_name' => 'no_fill',
                    'heading' => esc_html_x( 'Do not fill content area?', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Do not fill content area with color.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'spacing',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        '1px' => '1',
                        '2px' => '2',
                        '3px' => '3',
                        '4px' => '4',
                        '5px' => '5',
                        '10px' => '10',
                        '15px' => '15',
                        '20px' => '20',
                        '25px' => '25',
                        '30px' => '30',
                        '35px' => '35',
                    ),
                    'heading' => esc_html_x( 'Spacing', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion spacing.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'gap',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        '1px' => '1',
                        '2px' => '2',
                        '3px' => '3',
                        '4px' => '4',
                        '5px' => '5',
                        '10px' => '10',
                        '15px' => '15',
                        '20px' => '20',
                        '25px' => '25',
                        '30px' => '30',
                        '35px' => '35',
                    ),
                    'heading' => esc_html_x( 'Gap', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion gap.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'c_align',
                    'value' => array(
                        esc_html_x( 'Left', 'admin-view', 'vayne' ) => 'left',
                        esc_html_x( 'Right', 'admin-view', 'vayne' ) => 'right',
                        esc_html_x( 'Center', 'admin-view', 'vayne' ) => 'center',
                    ),
                    'heading' => esc_html_x( 'Alignment', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion section title alignment.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'autoplay',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => 'none',
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '5' => '5',
                        '10' => '10',
                        '20' => '20',
                        '30' => '30',
                        '40' => '40',
                        '50' => '50',
                        '60' => '60',
                    ),
                    'std' => 'none',
                    'heading' => esc_html_x( 'Autoplay', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select auto rotate for accordion in seconds (Note: disabled by default).', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'checkbox',
                    'param_name' => 'collapsible_all',
                    'heading' => esc_html_x( 'Allow collapse all?', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Allow collapse all accordion sections.', 'admin-view', 'vayne' ),
                ),
                // Control Icons
                array(
                    'type' => 'dropdown',
                    'param_name' => 'c_icon',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        esc_html_x( 'Chevron', 'admin-view', 'vayne' ) => 'chevron',
                        esc_html_x( 'Plus', 'admin-view', 'vayne' ) => 'plus',
                        esc_html_x( 'Triangle', 'admin-view', 'vayne' ) => 'triangle',
                    ),
                    'std' => 'plus',
                    'heading' => esc_html_x( 'Icon', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion navigation icon.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'c_position',
                    'value' => array(
                        esc_html_x( 'Left', 'admin-view', 'vayne' ) => 'left',
                        esc_html_x( 'Right', 'admin-view', 'vayne' ) => 'right',
                    ),
                    'dependency' => array(
                        'element' => 'c_icon',
                        'not_empty' => true,
                    ),
                    'heading' => esc_html_x( 'Position', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select accordion navigation icon position.', 'admin-view', 'vayne' ),
                ),
                // Control Icons END
                array(
                    'type' => 'textfield',
                    'param_name' => 'active_section',
                    'heading' => esc_html_x( 'Active section', 'admin-view', 'vayne' ),
                    'value' => 1,
                    'description' => esc_html_x( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html_x( 'Extra class name', 'admin-view', 'vayne' ),
                    'param_name' => 'el_class',
                    'description' => esc_html_x( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'admin-view', 'vayne' ),
                ),
            )
        ));
    }

    public function overrideTtaTabs(){
        vc_map_update( 'vc_tta_tabs', array(
            'category' => $this->category,
            'params' => array(
                array(
                    'type' => 'textfield',
                    'param_name' => 'title',
                    'heading' => esc_html_x( 'Widget title', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Enter text used as widget title (Note: located above content element).', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'style',
                    'value' => array(
                        esc_html_x( 'Vayne 01', 'admin-view', 'vayne' ) => 'la-1',
                        esc_html_x( 'Vayne 02', 'admin-view', 'vayne' ) => 'la-2',
                        esc_html_x( 'Vayne 03', 'admin-view', 'vayne' ) => 'la-3',
                        esc_html_x( 'Vayne 04', 'admin-view', 'vayne' ) => 'la-4',
                        esc_html_x( 'Vayne 05', 'admin-view', 'vayne' ) => 'la-5',
                        esc_html_x( 'Classic', 'admin-view', 'vayne' ) => 'classic',
                        esc_html_x( 'Modern', 'admin-view', 'vayne' ) => 'modern',
                        esc_html_x( 'Flat', 'admin-view', 'vayne' ) => 'flat',
                        esc_html_x( 'Outline', 'admin-view', 'vayne' ) => 'outline',
                    ),
                    'heading' => esc_html_x( 'Style', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs display style.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'shape',
                    'value' => array(
                        esc_html_x( 'Rounded', 'admin-view', 'vayne' ) => 'rounded',
                        esc_html_x( 'Square', 'admin-view', 'vayne' ) => 'square',
                        esc_html_x( 'Round', 'admin-view', 'vayne' ) => 'round',
                    ),
                    'heading' => esc_html_x( 'Shape', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs shape.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'color',
                    'heading' => esc_html_x( 'Color', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs color.', 'admin-view', 'vayne' ),
                    'value' => getVcShared( 'colors-dashed' ),
                    'std' => 'grey',
                    'param_holder_class' => 'vc_colored-dropdown',
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),

                array(
                    'type' => 'checkbox',
                    'param_name' => 'no_fill_content_area',
                    'heading' => esc_html_x( 'Do not fill content area?', 'admin-view', 'vayne' ),
                    'std' => 'true',
                    'description' => esc_html_x( 'Do not fill content area with color.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'spacing',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        '1px' => '1',
                        '2px' => '2',
                        '3px' => '3',
                        '4px' => '4',
                        '5px' => '5',
                        '10px' => '10',
                        '15px' => '15',
                        '20px' => '20',
                        '25px' => '25',
                        '30px' => '30',
                        '35px' => '35',
                    ),
                    'heading' => esc_html_x( 'Spacing', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs spacing.', 'admin-view', 'vayne' ),
                    'std' => '',
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'gap',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        '1px' => '1',
                        '2px' => '2',
                        '3px' => '3',
                        '4px' => '4',
                        '5px' => '5',
                        '10px' => '10',
                        '15px' => '15',
                        '20px' => '20',
                        '25px' => '25',
                        '30px' => '30',
                        '35px' => '35',
                    ),
                    'heading' => esc_html_x( 'Gap', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs gap.', 'admin-view', 'vayne' ),
                    'std' => '',
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'tab_position',
                    'value' => array(
                        esc_html_x( 'Top', 'admin-view', 'vayne' ) => 'top',
                        esc_html_x( 'Bottom', 'admin-view', 'vayne' ) => 'bottom',
                    ),
                    'heading' => esc_html_x( 'Position', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs navigation position.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'alignment',
                    'value' => array(
                        esc_html_x( 'Left', 'admin-view', 'vayne' ) => 'left',
                        esc_html_x( 'Right', 'admin-view', 'vayne' ) => 'right',
                        esc_html_x( 'Center', 'admin-view', 'vayne' ) => 'center',
                    ),
                    'heading' => esc_html_x( 'Alignment', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs section title alignment.', 'admin-view', 'vayne' ),
                    'std' => 'center',
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'autoplay',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => 'none',
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '5' => '5',
                        '10' => '10',
                        '20' => '20',
                        '30' => '30',
                        '40' => '40',
                        '50' => '50',
                        '60' => '60',
                    ),
                    'std' => 'none',
                    'heading' => esc_html_x( 'Autoplay', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select auto rotate for tabs in seconds (Note: disabled by default).', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'textfield',
                    'param_name' => 'active_section',
                    'heading' => esc_html_x( 'Active section', 'admin-view', 'vayne' ),
                    'value' => 1,
                    'description' => esc_html_x( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'pagination_style',
                    'value' => array(
                        esc_html_x( 'None', 'admin-view', 'vayne' ) => '',
                        esc_html_x( 'Square Dots', 'admin-view', 'vayne' ) => 'outline-square',
                        esc_html_x( 'Radio Dots', 'admin-view', 'vayne' ) => 'outline-round',
                        esc_html_x( 'Point Dots', 'admin-view', 'vayne' ) => 'flat-round',
                        esc_html_x( 'Fill Square Dots', 'admin-view', 'vayne' ) => 'flat-square',
                        esc_html_x( 'Rounded Fill Square Dots', 'admin-view', 'vayne' ) => 'flat-rounded',
                    ),
                    'heading' => esc_html_x( 'Pagination style', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select pagination style.', 'admin-view', 'vayne' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('classic','modern','flat','outline')
                    ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'pagination_color',
                    'value' => getVcShared( 'colors-dashed' ),
                    'heading' => esc_html_x( 'Pagination color', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select pagination color.', 'admin-view', 'vayne' ),
                    'param_holder_class' => 'vc_colored-dropdown',
                    'std' => 'grey',
                    'dependency' => array(
                        'element' => 'pagination_style',
                        'not_empty' => true,
                    ),
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html_x( 'Extra class name', 'admin-view', 'vayne' ),
                    'param_name' => 'el_class',
                    'description' => esc_html_x( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html_x( 'CSS box', 'admin-view', 'vayne' ),
                    'param_name' => 'css',
                    'group' => esc_html_x( 'Design Options', 'admin-view', 'vayne' ),
                ),
            )
        ));
    }

    public function overrideTtaSection(){
        $shortcode_tag = 'vc_tta_section';
        $shortcode_object = vc_get_shortcode($shortcode_tag);
        $shortcode_params = $shortcode_object['params'];
        $i_type_idx = self::getParamIndex($shortcode_params,'i_type');
        $el_class_idx = self::getParamIndex($shortcode_params,'el_class');
        if($i_type_idx !== -1 && $el_class_idx !== -1){
            $el_class = $shortcode_params[$el_class_idx];
            $shortcode_params[$i_type_idx]['value'][esc_html_x('LaStudio Icon Outline', 'admin-view', 'vayne')] = 'la_icon_outline';
            $shortcode_params[$el_class_idx] = array (
                'type' => 'iconpicker',
                'heading' => esc_html_x( 'Icon', 'admin-view', 'vayne' ),
                'param_name' => 'i_icon_la_icon_outline',
                'value' => 'la-icon design-2_image',
                'settings' => array(
                    'emptyIcon' => false,
                    'type' => 'la_icon_outline',
                    'iconsPerPage' => 50,
                ),
                'dependency' => array(
                    'element' => 'i_type',
                    'value' => 'la_icon_outline',
                )
            );
            $shortcode_params[] = $el_class;
            vc_map_update($shortcode_tag , array(
                'params' => $shortcode_params
            ));
        }
    }

    public function modifyTtaTabsClasses($classes, $atts){
        if(isset($atts['style']) && strpos($atts['style'],'la-') !== false && isset($atts['alignment'])){
            $classes[] = 'vc_tta-' . $atts['style'];
            $classes[] = 'vc_tta-alignment-' . $atts['alignment'];
        }
        return $classes;
    }

    public function overrideTtaTour(){
        vc_map_update( 'vc_tta_tour', array(
            'category' => $this->category,
            'params' => array(
                array(
                    'type' => 'dropdown',
                    'param_name' => 'style',
                    'value' => array(
                        esc_html_x( 'Vayne 01', 'admin-view', 'vayne' ) => 'la-1',
                    ),
                    'heading' => esc_html_x( 'Style', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs display style.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'tab_position',
                    'value' => array(
                        esc_html_x( 'Left', 'admin-view', 'vayne' ) => 'left',
                        esc_html_x( 'Right', 'admin-view', 'vayne' ) => 'right',
                    ),
                    'heading' => esc_html_x( 'Position', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tour navigation position.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'alignment',
                    'value' => array(
                        esc_html_x( 'Left', 'admin-view', 'vayne' ) => 'left',
                        esc_html_x( 'Right', 'admin-view', 'vayne' ) => 'right',
                        esc_html_x( 'Center', 'admin-view', 'vayne' ) => 'center',
                    ),
                    'heading' => esc_html_x( 'Alignment', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tabs section title alignment.', 'admin-view', 'vayne' ),
                    'std' => 'center',
                ),
                array(
                    'type' => 'hidden',
                    'param_name' => 'autoplay',
                    'std' => 'none',
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'controls_size',
                    'value' => array(
                        esc_html_x( 'Auto', 'admin-view', 'vayne' ) => '',
                        esc_html_x( 'Extra large', 'admin-view', 'vayne' ) => 'xl',
                        esc_html_x( 'Large', 'admin-view', 'vayne' ) => 'lg',
                        esc_html_x( 'Medium', 'admin-view', 'vayne' ) => 'md',
                        esc_html_x( 'Small', 'admin-view', 'vayne' ) => 'sm',
                        esc_html_x( 'Extra small', 'admin-view', 'vayne' ) => 'xs',
                    ),
                    'heading' => esc_html_x( 'Navigation width', 'admin-view', 'vayne' ),
                    'description' => esc_html_x( 'Select tour navigation width.', 'admin-view', 'vayne' ),
                ),

                array(
                    'type' => 'textfield',
                    'param_name' => 'active_section',
                    'heading' => esc_html_x( 'Active section', 'admin-view', 'vayne' ),
                    'value' => 1,
                    'description' => esc_html_x( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html_x( 'Extra class name', 'admin-view', 'vayne' ),
                    'param_name' => 'el_class',
                    'description' => esc_html_x( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'admin-view', 'vayne' ),
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html_x( 'CSS box', 'admin-view', 'vayne' ),
                    'param_name' => 'css',
                    'group' => esc_html_x( 'Design Options', 'admin-view', 'vayne' ),
                ),
            )
        ));
    }

    public function overrideVcSection(){
        vc_add_params('vc_section', array(
            array(
                'type' => 'dropdown',
                'heading' => esc_html_x('Section Behaviour', 'admin-view', 'vayne'),
                'param_name' => 'fp_auto_height',
                'admin_label' => true,
                'value' => array(
                    esc_html_x('Full Height', 'admin-view', 'vayne') => 'off',
                    esc_html_x('Auto Height', 'admin-view', 'vayne') => 'on',
                    esc_html_x('Responsive Auto Height', 'admin-view', 'vayne') => 'responsive',
                    esc_html_x('Top Fixed Header', 'admin-view', 'vayne') => 'fixed_top',
                    esc_html_x('Bottom Fixed Footer', 'admin-view', 'vayne') => 'fixed_bottom',
                ),
                'description' => esc_html_x('Select section row behaviour.', 'admin-view', 'vayne'),
                'group' => esc_html_x('One Page Settings', 'admin-view', 'vayne'),
            ),
            array(
                'type' => 'textfield',
                'class' => '',
                'heading' => esc_html_x('Anchor', 'admin-view', 'vayne'),
                'param_name' => 'fp_anchor',
                'admin_label'   => true,
                'value' => '',
                'description' => esc_html_x('Enter an anchor (ID).', 'admin-view', 'vayne'),
                'dependency' => array('element' => 'fp_auto_height', 'value' => array('off', 'on', 'responsive')),
                'group' => esc_html_x('One Page Settings', 'admin-view', 'vayne'),
            ),
            array(
                'type' => 'textfield',
                'class' => '',
                'heading' => esc_html_x('Tooltip', 'admin-view', 'vayne'),
                'param_name' => 'fp_tooltip',
                'dependency' => array('element' => 'fp_auto_height', 'value' => array('off', 'on', 'responsive')),
                'value' => '',
                'group' => esc_html_x('One Page Settings', 'admin-view', 'vayne'),
            ),
            array(
                'type' => 'checkbox',
                'class' => '',
                'heading' => esc_html_x('Rows as Slides', 'admin-view', 'vayne'),
                'param_name' => 'fp_column_slide',
                'dependency' => array('element' => 'fp_auto_height', 'value' => array('off', 'on', 'responsive')),
                'value' => '',
                'group' => esc_html_x('One Page Settings', 'admin-view', 'vayne'),
                'description' => esc_html_x('Enable if you want to show each row in this section as slides.', 'admin-view', 'vayne'),
            ),
            array(
                'type' => 'checkbox',
                'class' => '',
                'heading' => esc_html_x('No Scrollbars', 'admin-view', 'vayne'),
                'param_name' => 'fp_no_scrollbar',
                'dependency' => array('element' => 'fp_auto_height', 'value' => array('off', 'on', 'responsive')),
                'value' => '',
                'group' => esc_html_x('One Page Settings', 'admin-view', 'vayne'),
                'description' => esc_html_x('Enable if scrolloverflow is enabled but you don\'t want to show scrollbars for this section.', 'admin-view', 'vayne'),
            )
        ));
    }

    protected function arrayToObject($array) {
        if (!is_array($array)) {
            return $array;
        }
        $object = new stdClass();
        if (is_array($array) && count($array) > 0) {
            foreach ($array as $name=>$value) {
                $name = strtolower(trim($name));
                if (!empty($name)) {
                    $object->$name = $this->arrayToObject($value);
                }
            }
            return $object;
        }
        else {
            return false;
        }
    }

    public static function getParamIndex($array, $attr){
        foreach ($array as $index => $entry) {
            if ($entry['param_name'] == $attr) {
                return $index;
            }
        }
        return -1;
    }

}