<?php if ( ! defined( 'ABSPATH' ) ) { die; }

add_filter('LaStudio/global_loop_variable', 'vayne_set_loop_variable');
if(!function_exists('vayne_set_loop_variable')){
    function vayne_set_loop_variable( $var = ''){
        return 'vayne_loop';
    }
}

add_filter('lastudio/google_map_api', 'vayne_add_googlemap_api');
if(!function_exists('vayne_add_googlemap_api')){
    function vayne_add_googlemap_api( $key = '' ){
        return Vayne()->settings->get('google_key', $key);
    }
}

add_filter('vayne/filter/page_title', 'vayne_override_page_title_bar_title');
if(!function_exists('vayne_override_page_title_bar_title')){
    function vayne_override_page_title_bar_title( $title ){

        $_tmp = '<header><div class="page-title h2">%s</div></header>';

        $context = (array) Vayne()->get_current_context();

        if(in_array('is_singular', $context)){
            $custom_title = Vayne()->settings->get_post_meta( get_queried_object_id(), 'page_title_custom');
            if(!empty( $custom_title) ){
                return sprintf($_tmp, $custom_title);
            }
        }

        if(in_array('is_tax', $context) || in_array('is_category', $context) || in_array('is_tag', $context)){
            $custom_title = Vayne()->settings->get_term_meta( get_queried_object_id(), 'page_title_custom');
            if(!empty( $custom_title) ){
                return sprintf($_tmp, $custom_title);
            }
        }

        return $title;
    }
}

add_action( 'pre_get_posts', 'vayne_set_posts_per_page_for_portfolio_cpt' );
if(!function_exists('vayne_set_posts_per_page_for_portfolio_cpt')){
    function vayne_set_posts_per_page_for_portfolio_cpt( $query ) {
        if ( !is_admin() && $query->is_main_query() ) {
            if( is_post_type_archive( 'la_portfolio' ) || is_tax(get_object_taxonomies( 'la_portfolio' ))){
                $pf_per_page = (int) Vayne()->settings->get('portfolio_per_page', 9);
                $query->set( 'posts_per_page', $pf_per_page );
            }
        }
    }
}

add_filter('yith_wc_social_login_icon', 'vayne_override_yith_wc_social_login_icon', 10, 3);
if(!function_exists('vayne_override_yith_wc_social_login_icon')){
    function vayne_override_yith_wc_social_login_icon($social, $key, $args){
        if(!is_admin()){
            $social = sprintf(
                '<a class="%s" href="%s">%s</a>',
                'social_login ywsl-' . esc_attr($key) . ' social_login-' . esc_attr($key),
                $args['url'],
                isset( $args['value']['label'] ) ? $args['value']['label'] : $args['value']
            );
        }
        return $social;
    }
}

add_action('wp', 'vayne_hook_maintenance');
if(!function_exists('vayne_hook_maintenance')){
    function vayne_hook_maintenance(){
        wp_reset_postdata();
        $enable_private = Vayne()->settings->get('enable_maintenance', 'no');
        if($enable_private == 'yes'){
            if(!is_user_logged_in()){
                $page_id = Vayne()->settings->get('maintenance_page');
                if(empty($page_id)){
                    wp_redirect(wp_login_url());
                    exit;
                }
                else{
                    $page_id = absint($page_id);
                    if(!is_page($page_id)){
                        wp_redirect(get_permalink($page_id));
                        exit;
                    }
                }
            }
        }
    }
}

add_filter('widget_archives_args', 'vayne_modify_widget_archives_args');
if(!function_exists('vayne_modify_widget_archives_args')){
    function vayne_modify_widget_archives_args( $args ){
        if(isset($args['show_post_count'])){
            unset($args['show_post_count']);
        }
        return $args;
    }
}
if(isset($_GET['la_doing_ajax'])){
    remove_action('template_redirect', 'redirect_canonical');
}
add_filter('woocommerce_redirect_single_search_result', '__return_false');


/**
 * Ensure that a specific theme is never updated. This works by removing the
 * theme from the list of available updates.
 */

add_filter('http_request_args', 'vayne_hidden_theme_update', 10, 2);

if(!function_exists('vayne_hidden_theme_update')){
    function vayne_hidden_theme_update( $response, $url ){
        $pos = strpos($url, '//api.wordpress.org/themes/update-check');
        if($pos === 5 || $pos === 6){
            $themes = json_decode( $response['body']['themes'], true );
            if(isset($themes['themes']['vayne'])){
                unset($themes['themes']['vayne']);
            }
            if(isset($themes['themes']['vayne-child'])){
                unset($themes['themes']['vayne-child']);
            }
            $response['body']['themes'] = json_encode( $themes );
        }
        return $response;
    }
}



add_filter('vayne/filter/breadcrumbs/items', 'vayne_theme_setup_breadcrumbs_for_dokan', 10, 2);
if(!function_exists('vayne_theme_setup_breadcrumbs_for_dokan')){
    function vayne_theme_setup_breadcrumbs_for_dokan( $items, $args ){
        if (  function_exists('dokan_is_store_page') && dokan_is_store_page() ) {

            $custom_store_url = dokan_get_option( 'custom_store_url', 'dokan_general', 'store' );

            $author      = get_query_var( $custom_store_url );
            $seller_info = get_user_by( 'slug', $author );

            $items[] = sprintf(
                '<div class="la-breadcrumb-item"><a href="%4$s" class="%2$s" rel="tag" title="%3$s">%1$s</a></div>',
                esc_attr(ucwords($custom_store_url)),
                'la-breadcrumb-item-link',
                esc_attr(ucwords($custom_store_url)),
                esc_url(site_url() .'/'.$custom_store_url)
            );
            $items[] = sprintf(
                '<div class="la-breadcrumb-item"><span class="%2$s">%1$s</span></div>',
                esc_attr($seller_info->data->display_name),
                'la-breadcrumb-item-link'
            );
        }

        return $items;
    }
}


add_filter('vayne/filter/show_page_title', 'vayne_filter_show_page_title', 10, 1 );
add_filter('vayne/filter/show_breadcrumbs', 'vayne_filter_show_breadcrumbs', 10, 1 );

if(!function_exists('vayne_filter_show_page_title')){
    function vayne_filter_show_page_title( $show ){
        $context = Vayne()->get_current_context();
        if( in_array( 'is_product', $context ) && Vayne()->settings->get('product_single_hide_page_title', 'no') == 'yes' ){
            return false;
        }
        return $show;
    }
}

if(!function_exists('vayne_filter_show_breadcrumbs')){
    function vayne_filter_show_breadcrumbs( $show ){
        $context = Vayne()->get_current_context();
        if( in_array( 'is_product', $context ) && Vayne()->settings->get('product_single_hide_breadcrumb', 'no') == 'yes'){
            return false;
        }
        return $show;
    }
}


add_filter('LaStudio/swatches/args/show_option_none', 'vayne_allow_translate_woo_text_in_swatches', 10, 1);
if(!function_exists('vayne_allow_translate_woo_text_in_swatches')){
    function vayne_allow_translate_woo_text_in_swatches( $text ){
        return esc_html_x( 'Choose an option', 'front-view', 'vayne' );
    }
}

add_filter('LaStudio/swatches/get_attribute_thumbnail_src', 'vayne_allow_resize_image_url_in_swatches', 10, 4);

if(!function_exists('vayne_allow_resize_image_url_in_swatches')){
    function vayne_allow_resize_image_url_in_swatches( $image_url, $image_id, $size_name, $instance ) {
        if($size_name == 'la_swatches_image_size'){
            $width = $instance->get_width();
            $height = $instance->get_height();
            $image_url = Vayne()->images->get_attachment_image_url($image_id, array( $width, $height ));
            return $image_url;
        }
        return $image_url;
    }
}

add_filter('LaStudio/swatches/get_product_variation_image_url_by_attribute', 'vayne_allow_resize_variation_image_url_by_attribute_in_swatches', 10, 2);
if(!function_exists('vayne_allow_resize_variation_image_url_by_attribute_in_swatches')){
    function vayne_allow_resize_variation_image_url_by_attribute_in_swatches( $image_url, $image_id ) {
        global $vayne_loop;
        if(isset($vayne_loop['image_size'])){
            return Vayne()->images->get_attachment_image_url($image_id, $vayne_loop['image_size'] );
        }
        return $image_url;
    }
}




/**
 * This function allow get property of `woocommerce_loop` inside the loop
 * @since 1.0.1
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('vayne_get_wc_loop_prop')){
    function vayne_get_wc_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['woocommerce_loop'], $GLOBALS['woocommerce_loop'][ $prop ] ) ? $GLOBALS['woocommerce_loop'][ $prop ] : $default;
    }
}

/**
 * This function allow set property of `woocommerce_loop`
 * @since 1.0.1
 * @param string $prop Prop to set.
 * @param string $value Value to set.
 */

if(!function_exists('vayne_set_wc_loop_prop')){
    function vayne_set_wc_loop_prop( $prop, $value = ''){
        if(isset($GLOBALS['woocommerce_loop'])){
            $GLOBALS['woocommerce_loop'][ $prop ] = $value;
        }
    }
}

/**
 * This function allow get property of `vayne_loop` inside the loop
 * @since 1.0.1
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('vayne_get_theme_loop_prop')){
    function vayne_get_theme_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['vayne_loop'], $GLOBALS['vayne_loop'][ $prop ] ) ? $GLOBALS['vayne_loop'][ $prop ] : $default;
    }
}

remove_filter( 'woocommerce_product_loop_start', 'woocommerce_maybe_show_product_subcategories' );


/**
 * This hook allow to resize images to correct sizes
 * @since 1.0.2
 */
if(!function_exists('vayne_override_woothumbnail_size')){
    function vayne_override_woothumbnail_size( $size ) {
        if(!function_exists('wc_get_theme_support')){
            return $size;
        }
        $size['width'] = absint( wc_get_theme_support( 'gallery_thumbnail_image_width', 100 ) );
        $cropping      = get_option( 'woocommerce_thumbnail_cropping', '1:1' );

        if ( 'uncropped' === $cropping ) {
            $size['height'] = '';
            $size['crop']   = 0;
        }
        elseif ( 'custom' === $cropping ) {
            $width          = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_width', '4' ) );
            $height         = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_height', '3' ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }
        else {
            $cropping_split = explode( ':', $cropping );
            $width          = max( 1, current( $cropping_split ) );
            $height         = max( 1, end( $cropping_split ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }

        return $size;
    }
    add_filter('woocommerce_get_image_size_gallery_thumbnail', 'vayne_override_woothumbnail_size');
}

/**
 * This hook allow to remove all the shortcode from the raw format content
 * @since 1.0.2
 */
if(!function_exists('vayne_override_filter_woocommerce_format_content')){
    function vayne_override_filter_woocommerce_format_content( $format, $raw_string ){
        $format = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $raw_string);
        return apply_filters( 'woocommerce_short_description', $format );
    }
    add_filter('woocommerce_format_content', 'vayne_override_filter_woocommerce_format_content', 99, 2);
}

/**
 *
 * @since 1.0.2
 */
if(!function_exists('vayne_wc_product_loop')){
    function vayne_wc_product_loop(){
        if(!function_exists('WC')){
            return false;
        }
        return have_posts() || 'products' !== woocommerce_get_loop_display_mode();
    }
}

add_action( 'wp_ajax_lastudio_ig_feed', 'vayne_ajax_get_ig_feed' );
add_action( 'wp_ajax_nopriv_lastudio_ig_feed', 'vayne_ajax_get_ig_feed' );

if(!function_exists('vayne_ajax_get_ig_feed')){
    function vayne_ajax_get_ig_feed(){
        // check token first;
        $token = Vayne()->settings->get('instagram_token', '');
        if(empty($token)){
            wp_send_json_error(['msg' => __('Invalid Token', 'vayne')]);
        }
        $life_time = get_transient('lastudio_ig_token');
        if(empty($life_time)){
            $ig_refresh_token_url = add_query_arg([
                'grant_type' => 'ig_refresh_token',
                'access_token' => $token
            ], 'https://graph.instagram.com/refresh_access_token');
            $response = wp_remote_get($ig_refresh_token_url);
            // request failed
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [1]', 'vayne')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [2]', 'vayne')]);
            }
            $body = wp_remote_retrieve_body($response);
            $body = json_decode($body, true);
            $expires_in = (int) $body['expires_in'] - DAY_IN_SECONDS;
            if($expires_in > 0){
                $token = $body['access_token'];
                $all_option = get_option(Vayne::get_option_name(), []);
                $all_option['instagram_token'] = $token;
                update_option(Vayne::get_option_name(), $all_option);
                set_transient('lastudio_ig_token', $body , $expires_in);
            }
            else{
                wp_send_json_error(['msg' => __('Token Expired [3]', 'vayne')]);
            }
        }

        $cache = get_transient('lastudio_ig_feed');
        if(empty($cache)){
            $ig_feed_url = add_query_arg([
                'fields'        => 'caption,media_type,media_url,thumbnail_url,permalink,timestamp',
                'access_token'  => $token,
                'limit'         => 20
            ], 'https://graph.instagram.com/me/media');

            $response = wp_remote_get($ig_feed_url);
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [4]', 'vayne')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [5]', 'vayne')]);
            }
            $data = wp_remote_retrieve_body($response);
            $data = json_decode($data, true);
            $cache = $data['data'];
            set_transient('lastudio_ig_feed', $cache, HOUR_IN_SECONDS * 12);
        }
        if(empty($cache)){
            wp_send_json_error(['msg' => __('Invalid Token [6]', 'vayne')]);
        }
        else{
            wp_send_json_success($cache);
        }
    }
}