<?php if ( ! defined( 'ABSPATH' ) ) { die; }

if(!function_exists('vayne_entry_meta_item_postdate')){
    function vayne_entry_meta_item_postdate(){
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated hidden" datetime="%3$s">%4$s</time>';
        }
        $time_string = sprintf( $time_string,
            esc_attr( get_the_date( 'c' ) ),
            esc_html( get_the_date() ),
            esc_attr( get_the_modified_date( 'c' ) ),
            esc_html( get_the_modified_date() )
        );
        printf(
            '<span class="posted-on"><i class="la-icon ui-2_time-clock"></i> <span class="screen-reader-text">%2$s </span><a href="%1$s" rel="bookmark">%3$s</a></span>',
            esc_url( get_permalink() ),
            esc_html_x('', 'front-view', 'vayne'),
            $time_string
        );
    }
}
if(!function_exists('vayne_entry_meta_item_author')){
    function vayne_entry_meta_item_author(){
        printf(
            '<span class="byline"><span class="author vcard"><i class="fa-user-o"></i><a class="url fn n" href="%1$s"><span class="screen-reader-text">%2$s </span>%3$s</a></span></span>',
            esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
            esc_html_x('by', 'front-view', 'vayne'),
            esc_html( get_the_author() )
        );
    }
}
if(!function_exists('vayne_entry_meta_item_category_list')){
    function vayne_entry_meta_item_category_list($before = '', $after = '', $separator = ', ', $parents = '', $post_id = false){
        add_filter('get_the_terms', 'vayne_exclude_demo_term_in_category');
        $categories_list = get_the_category_list('{{_}}', $parents, $post_id );
        remove_filter('get_the_terms', 'vayne_exclude_demo_term_in_category');
        if ( $categories_list ) {
            printf(
                '%3$s<span class="screen-reader-text">%1$s </span><span>%2$s</span>%4$s',
                esc_html_x('in', 'front-view', 'vayne'),
                str_replace('{{_}}', $separator, $categories_list),
                $before,
                $after
            );
        }
    }
}

if(!function_exists('vayne_exclude_demo_term_in_category')){
    function vayne_exclude_demo_term_in_category( $term ){
        return apply_filters('vayne/post_category_excluded', $term);
    }
}

if(!function_exists('vayne_entry_meta_item_comment_post_link')){
    function vayne_entry_meta_item_comment_post_link(){
        if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
            echo '<span class="comments-link">';
            comments_popup_link();
            echo '</span>';
        }
    }
}

if(!function_exists('vayne_entry_meta_item_comment_post_link_with_icon')){
    function vayne_entry_meta_item_comment_post_link_with_icon(){
        if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
            if(get_comments_number()){

            }
            echo '<span class="comments-link">';
            comments_popup_link('<i class="fa-comments"></i><span>0</span>', '<i class="fa-comments"></i><span>1</span>', '<i class="fa-comments"></i><span>%</span>');
            echo '</span>';
        }
    }
}

if(!function_exists('vayne_entry_meta_item_post_love')) {
    function vayne_entry_meta_item_post_love()
    {
        echo '<span class="post-love-count">';
        $post_love_count = get_post_meta(get_the_ID(), '_la_love_count', true);
        printf(
            '<a data-post-id="%s" href="%s">%s</a>',
            esc_attr(get_the_ID()),
            esc_url( get_permalink() ),
            absint($post_love_count)
        );
        echo '</span>';
    }
}

if(!function_exists('vayne_single_post_thumbnail')){
    function vayne_single_post_thumbnail( $thumbnail_size = 'full'){
        if ( post_password_required() || is_attachment() ) {
            return;
        }
        $flag_format_content = false;

        switch(get_post_format()){
            case 'link':
                $link = Vayne()->settings->get_post_meta( get_the_ID(), 'format_link' );
                if(!empty($link)){
                    printf(
                        '<div class="blog_item--thumbnail format-link" %2$s><div class="format-content">%1$s</div><a class="post-link-overlay" href="%1$s"></a></div>',
                        esc_url($link),
                        has_post_thumbnail() ? 'style="background-image:url('.Vayne()->images->get_post_thumbnail_url(get_the_ID()).')"' : ''
                    );
                    $flag_format_content = true;
                }
                break;
            case 'quote':
                $quote_content = Vayne()->settings->get_post_meta(get_the_ID(), 'format_quote_content');
                $quote_author = Vayne()->settings->get_post_meta(get_the_ID(), 'format_quote_author');
                $quote_background = Vayne()->settings->get_post_meta(get_the_ID(), 'format_quote_background');
                $quote_color = Vayne()->settings->get_post_meta(get_the_ID(), 'format_quote_color');
                if(!empty($quote_content)){
                    $quote_content = '<p class="format-quote-content">'. $quote_content .'</p>';
                    if(!empty($quote_author)){
                        $quote_content .= '<span class="quote-author">'. $quote_author .'</span>';
                    }
                    $styles = array();
                    $styles[] = 'background-color:' . $quote_background;
                    $styles[] = 'color:' . $quote_color;
                    printf(
                        '<div class="blog_item--thumbnail format-quote" style="%3$s"><div class="format-content">%1$s</div><a class="post-link-overlay" href="%2$s"></a></div>',
                        $quote_content,
                        get_the_permalink(),
                        esc_attr( implode(';', $styles) )
                    );
                    $flag_format_content = true;
                }

                break;

            case 'gallery':
                $ids = Vayne()->settings->get_post_meta(get_the_ID(), 'format_gallery');
                $ids = explode(',', $ids);
                $ids = array_map('trim', $ids);
                $ids = array_map('absint', $ids);
                $__tmp = '';
                if(!empty( $ids )){
                    foreach($ids as $image_id){
                        $__tmp .= sprintf('<div><a href="%1$s">%2$s</a></div>',
                            get_the_permalink(),
                            Vayne()->images->get_attachment_image( $image_id, $thumbnail_size)
                        );
                    }
                }
                if(has_post_thumbnail()){
                    $__tmp .= sprintf('<div><a href="%1$s">%2$s</a></div>',
                        get_the_permalink(),
                        Vayne()->images->get_post_thumbnail(get_the_ID(), $thumbnail_size )
                    );
                }
                if(!empty($__tmp)){
                    printf(
                        '<div class="blog_item"><div class="blog_item--thumbnail format-gallery"><div data-la_component="AutoCarousel" class="js-el la-slick-slider" data-slider_config="%1$s">%2$s</div></div></div>',
                        esc_attr(json_encode(array(
                            'slidesToShow' => 1,
                            'slidesToScroll' => 1,
                            'dots' => false,
                            'arrows' => true,
                            'speed' => 300,
                            'autoplay' => false,
                            'prevArrow'=> '<button type="button" class="slick-prev"><i class="fa fa-angle-left"></i></button>',
                            'nextArrow'=> '<button type="button" class="slick-next"><i class="fa fa-angle-right"></i></button>'
                        ))),
                        $__tmp
                    );
                    $flag_format_content = true;
                }
                break;

            case 'audio':
            case 'video':
                $embed_source = Vayne()->settings->get_post_meta(get_the_ID(), 'format_embed');
                $embed_aspect_ration = Vayne()->settings->get_post_meta(get_the_ID(), 'format_embed_aspect_ration');
                if(!empty($embed_source)){
                    $flag_format_content = true;
                    printf(
                        '<div class="blog_item--thumbnail format-embed"><div class="la-media-wrapper la-media-aspect-%2$s">%1$s</div></div>',
                        $embed_source,
                        esc_attr($embed_aspect_ration ? $embed_aspect_ration : 'origin')
                    );
                }
                break;
        }

        if(!$flag_format_content && has_post_thumbnail()){ ?>
            <div class="entry-thumbnail">
                <a href="<?php the_permalink();?>">
                    <?php Vayne()->images->the_post_thumbnail(get_the_ID(), $thumbnail_size); ?>
                    <span class="pf-icon pf-icon-<?php echo get_post_format() ? get_post_format() : 'standard' ?>"></span>
                </a>
            </div>
            <?php
        }

    }
}

if(!function_exists('vayne_social_sharing')){
    function vayne_social_sharing( $post_link = '', $post_title = '', $image = '', $post_excerpt = '', $echo = true){
        if(empty($post_link) || empty($post_title)){
            return;
        }
        if(!$echo){
            ob_start();
        }
        echo '<div class="social--sharing">';
        if(Vayne()->settings->get('sharing_facebook') || 'on' == Vayne()->settings->get('sharing_facebook')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="facebook" title="%2$s"><i class="fa fa-facebook"></i></a>',
                esc_url( 'https://www.facebook.com/sharer.php?u=' . $post_link ),
                esc_attr_x('Share this post on Facebook', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_twitter') || 'on' == Vayne()->settings->get('sharing_twitter')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="twitter" title="%2$s"><i class="fa fa-twitter"></i></a>',
                esc_url( 'https://twitter.com/intent/tweet?text=' . $post_title . '&url=' . $post_link ),
                esc_attr_x('Share this post on Twitter', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_pinterest') || 'on' == Vayne()->settings->get('sharing_pinterest')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="pinterest" title="%2$s"><i class="fa fa-pinterest-p"></i></a>',
                esc_url( 'https://pinterest.com/pin/create/button/?url=' . $post_link . '&media=' . $image . '&description=' . $post_title) ,
                esc_attr_x('Share this post on Pinterest', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_reddit') || 'on' == Vayne()->settings->get('sharing_reddit')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="reddit" title="%2$s"><i class="fa fa-reddit"></i></a>',
                esc_url( 'https://www.reddit.com/submit?url=' . $post_link . '&title=' . $post_title ),
                esc_attr_x('Share this post on Reddit', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_linkedin') || 'on' == Vayne()->settings->get('sharing_linkedin')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="linkedin" title="%2$s"><i class="fa fa-linkedin"></i></a>',
                esc_url( 'https://www.linkedin.com/shareArticle?mini=true&url=' . $post_link . '&title=' . $post_title ),
                esc_attr_x('Share this post on Linked In', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_google_plus') || 'on' == Vayne()->settings->get('sharing_google_plus')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="google-plus" title="%2$s"><i class="fa fa-google-plus"></i></a>',
                esc_url( 'https://plus.google.com/share?url=' . $post_link ),
                esc_attr_x('Share this post on Google Plus', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_tumblr') || 'on' == Vayne()->settings->get('sharing_tumblr')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="tumblr" title="%2$s"><i class="fa fa-tumblr"></i></a>',
                esc_url( 'https://www.tumblr.com/share/link?url=' . $post_link ) ,
                esc_attr_x('Share this post on Tumblr', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_vk') || 'on' == Vayne()->settings->get('sharing_vk')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="vk" title="%2$s"><i class="fa fa-vk"></i></a>',
                esc_url( 'http://vkontakte.ru/share.php?url=' . $post_link . '&title=' . $post_title ) ,
                esc_attr_x('Share this post on VK', 'front-view', 'vayne')
            );
        }
        if(Vayne()->settings->get('sharing_email') || 'on' == Vayne()->settings->get('sharing_email')){
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="email" title="%2$s"><i class="fa fa-envelope"></i></a>',
                esc_url( 'mailto:?subject=' . $post_title . '&body=' . $post_link ),
                esc_attr_x('Share this post via Email', 'front-view', 'vayne')
            );
        }
        echo '</div>';
        if(!$echo){
            return ob_get_clean();
        }
    }
}

if(!function_exists('vayne_the_pagination')){
    function vayne_the_pagination($args = array(), $query = null) {
        if(null === $query) {
            $query = $GLOBALS['wp_query'];
        }
        if($query->max_num_pages < 2) {
            return;
        }
        $paged        = get_query_var('paged') ? intval(get_query_var('paged')) : 1;
        $pagenum_link = html_entity_decode(get_pagenum_link());
        $wp_rewrite  = $GLOBALS['wp_rewrite'];
        $query_args   = array();
        $url_parts    = explode('?', $pagenum_link);
        if(isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $format  = $wp_rewrite->using_index_permalinks() && ! strpos($pagenum_link, 'index.php') ? 'index.php/' : '';
        $format .= $wp_rewrite->using_permalinks() ? user_trailingslashit('page/%#%', 'paged') : '?paged=%#%';
        printf('<div class="la-pagination">%s</div>',
            paginate_links(array_merge(array(
                'base'     => $pagenum_link,
                'format'   => $format,
                'total'    => $query->max_num_pages,
                'current'  => $paged,
                'mid_size' => 1,
                'add_args' => array_map('urlencode', $query_args),
                'prev_text'    => esc_html_x('Prev', 'front-view', 'vayne'),
                'next_text'    => esc_html_x('Next', 'front-view', 'vayne'),
                'type'         => 'list'
            ), $args))
        );
    }
}

if(!function_exists('vayne_get_social_media')){
    function vayne_get_social_media( $style = 'default', $el_class = ''){
        $css_class = implode(' ', array(
                'social-media-link',
                'style-' . $style
            )) ;
        $css_class .= ' ' . $el_class;

        $social_links = Vayne()->settings->get('social_links', array());
        if(!empty($social_links)){
            echo '<div class="'.esc_attr($css_class).'">';
            foreach($social_links as $item){
                if(!empty($item['link']) && !empty($item['icon'])){
                    $title = isset($item['title']) ? $item['title'] : '';
                    printf(
                        '<a href="%1$s" class="%2$s" title="%3$s" target="_blank" rel="nofollow"><i class="%4$s"></i></a>',
                        esc_url($item['link']),
                        esc_attr(sanitize_title($title)),
                        esc_attr($title),
                        esc_attr($item['icon'])
                    );
                }
            }
            echo '</div>';
        }
    }
}
if(!function_exists('vayne_get_portfolio_social_media')){
    function vayne_get_portfolio_social_media($post_id = 0, $el_class = ''){

        $css_class = 'social--sharing ' . $el_class;

        $social_links = Vayne()->settings->get_post_meta($post_id,'social_links');

        if(!empty($social_links) && is_array($social_links)){
            echo '<div class="'.esc_attr($css_class).'">';
            foreach($social_links as $item){
                if(!empty($item['link']) && !empty($item['icon'])){
                    $title = isset($item['title']) ? $item['title'] : '';
                    $custom_style = array();
                    if(!empty($item['text_color'])){
                        $custom_style[] = "color:" .$item['text_color'];
                    }
                    if(!empty($item['bg_color'])){
                        $custom_style[] = "background-color:" .$item['bg_color'];
                    }
                    printf(
                        '<a href="%1$s" class="%2$s" title="%3$s" style="%5$s" target="_blank" rel="nofollow"><i class="%4$s"></i></a>',
                        esc_url($item['link']),
                        esc_attr(sanitize_title($title)),
                        esc_attr($title),
                        esc_attr($item['icon']),
                        esc_attr(implode(';', $custom_style))
                    );
                }
            }
            echo '</div>';
        }
    }
}

if(!function_exists('vayne_comment_form_callback')) {
    function vayne_comment_form_callback($comment, $args, $depth){
        switch ($comment->comment_type) :
            case 'pingback' :
            case 'trackback' :
                ?>
                <li id="pingback-comment-<?php comment_ID(); ?>">
                <p class="cmt-pingback"><?php echo esc_html_x('Pingback:', 'front-view', 'vayne'); ?><?php comment_author_link(); ?><?php edit_comment_link(esc_html_x('Edit', 'front-view', 'vayne'), '<span class="ping-meta"><span class="edit-link">', '</span></span>'); ?></p>
                <?php
                break;
            default :
                // Proceed with normal comments.
                ?>
            <li id="li-comment-<?php echo esc_attr(get_comment_ID()); ?>" <?php comment_class('clearfix'); ?>>
                <div id="comment-<?php echo esc_attr(get_comment_ID()); ?>" class="comment_container clearfix">
                    <?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
                    <div class="comment-text">
                        <div class="comment-author"><?php comment_author_link(); ?></div>
                        <div class="comment-meta"><?php
                            printf( '<time datetime="%1$s">%2$s</time>',
                                get_comment_time( 'c' ),
                                sprintf( esc_html_x( '%1$s', '1: date', 'vayne' ), get_comment_date() )
                            );
                            edit_comment_link( esc_html_x( 'Edit', 'front-view', 'vayne' ), ' <span class="edit-link">', '</span>' ); ?>
                            <?php if ( '0' == $comment->comment_approved ) : ?>
                                <em class="comment-awaiting-moderation"><?php echo esc_html_x( 'Your comment is awaiting moderation.', 'front-view', 'vayne' ); ?></em>
                            <?php endif; ?></div>
                        <div class="description"><?php comment_text(); ?></div>
                        <div class="comment-footer"><div class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></div></div>
                    </div>
                </div>
                <?php
                break;
        endswitch;
    }
}

if(!function_exists('vayne_get_total_post_favorite')){
    function vayne_get_favorite_number_by_post_id( $post_id = 0 ){
        if(empty($post_id)){
            $post_id = get_the_ID();
        }
        return (int) get_post_meta( $post_id, 'la_total_favorites', true);
    }
}

if(!function_exists('vayne_get_favorite_link')){
    function vayne_get_favorite_link( $post_id = 0 ){
        if(empty($post_id)){
            $post_id = get_the_ID();
        }
        $count = vayne_get_favorite_number_by_post_id( $post_id );
        $lists = Vayne()->favorite->get_favorite_lists();
        $class = '';
        if(in_array($post_id, $lists)){
            $class = 'added';
        }
        ?>
        <div class="la-favorite-link">
            <a class="<?php echo esc_attr($class); ?>" href="javascript:;" rel="nofollow" data-favorite_id="<?php echo esc_attr($post_id)?>"><i class="fa fa-thumbs-up"></i><span class="favorite_count"><?php echo esc_html($count); ?></span></a>
        </div>
    <?php
    }
}

if(!function_exists('vayne_add_user_social_links')){
	function vayne_add_user_social_links( $contact_methods ){
		/* Add user contact methods */
		$contact_methods['facebook']  = esc_html_x('Facebook Link', 'front-view', 'vayne');
		$contact_methods['twitter']   = esc_html_x('Twitter Link', 'front-view', 'vayne');
		$contact_methods['pinterest']   = esc_html_x('Pinterest Link', 'front-view', 'vayne');
		$contact_methods['instagram']   = esc_html_x('Instagram Link', 'front-view', 'vayne');
		$contact_methods['google_plus']   = esc_html_x('Google+ Link', 'front-view', 'vayne');
		
		unset( $contact_methods['aim'] );
		unset( $contact_methods['jabber'] );
		unset( $contact_methods['yim'] );

		return $contact_methods;
	}
	add_filter('user_contactmethods', 'vayne_add_user_social_links');
}

if(!function_exists('vayne_get_user_social_links')){
	function vayne_get_user_social_links() {
		echo '<div class="author-social-links">';
		if(!empty(get_the_author_meta('facebook'))) {
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="facebook" title="%2$s"><i class="fa fa-facebook"></i></a>',
                esc_url(get_the_author_meta('facebook')),
                esc_attr_x("View author's Facebook profile", 'front-view', 'vayne')
            );
		}
		if(!empty(get_the_author_meta('twitter'))) {
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="twitter" title="%2$s"><i class="fa fa-twitter"></i></a>',
                esc_url(get_the_author_meta('twitter')),
                esc_attr_x("View author's Twitter profile", 'front-view', 'vayne')
            );
		}
		if(!empty(get_the_author_meta('pinterest'))) {
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="pinterest" title="%2$s"><i class="fa fa-pinterest-p"></i></a>',
                esc_url(get_the_author_meta('pinterest')),
                esc_attr_x("View author's Pinterest profile", 'front-view', 'vayne')
            );
		}
		if(!empty(get_the_author_meta('instagram'))) {
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="instagram" title="%2$s"><i class="fa fa-instagram"></i></a>',
                esc_url(get_the_author_meta('instagram')),
                esc_attr_x("View author's Instagram profile", 'front-view', 'vayne')
            );
		}
		if(!empty(get_the_author_meta('user_email'))) {
            printf('<a target="_blank" href="mailto:%1$s" rel="nofollow" class="email" title="%2$s"><i class="fa fa-envelope"></i></a>',
                esc_attr(get_the_author_meta('user_email')),
                esc_attr_x("Send an email for this author", 'front-view', 'vayne')
            );
		}
		if(!empty(get_the_author_meta('google_plus'))) {
            printf('<a target="_blank" href="%1$s" rel="nofollow" class="google-plus" title="%2$s"><i class="fa fa-google-plus"></i></a>',
                esc_url(get_the_author_meta('google_plus')),
                esc_attr_x("View author's Google+ profile", 'front-view', 'vayne')
            );
		}
		echo '</div>';
	}
}

if(!function_exists('vayne_comment_form_args')){
	function vayne_comment_form_args($args){
		$commenter = wp_get_current_commenter();
		$req      = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );
		$html_req = ( $req ? " required" : '' );
		unset($args['url']);
		$args['author'] = '<p class="comment-form-author"><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" maxlength="245" ' . $aria_req . $html_req . ' title="'. esc_html_x('Your name', 'front-view', 'vayne') . ( $req ? ' *' : '' ) .'" placeholder="'. esc_html_x('Your name', 'front-view', 'vayne') . ( $req ? ' *' : '' ) .'" /></p>';
		$args['email'] = '<p class="comment-form-email"><input id="email" name="email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" maxlength="100" aria-describedby="email-notes" ' . $aria_req . $html_req . ' title="'. esc_html_x('Email', 'front-view', 'vayne') . ( $req ? ' *' : '' ) .'" placeholder="'. esc_html_x('Email', 'front-view', 'vayne') . ( $req ? ' *' : '' ) .'" /></p>';
		return $args;
	}

	add_filter('comment_form_default_fields', 'vayne_comment_form_args');
}

if(!function_exists('vayne_comment_form_field_comment')){
	function vayne_comment_form_field_comment($field) {
		$field = '<p class="comment-form-comment"><textarea id="comment" name="comment" cols="45" rows="8" maxlength="65525" aria-required="true" required title="' . esc_html_x('Comment', 'front-view', 'vayne') . '" placeholder="' . esc_html_x('Comment', 'front-view', 'vayne') . '"></textarea></p>';
		return $field;
	}
	add_filter('comment_form_field_comment', 'vayne_comment_form_field_comment');
}

if(!function_exists('vayne_comment_form_fields')){
	function vayne_comment_form_fields( $fields ) {
		if ( isset( $fields['comment'] ) ) {
			$comment_field = $fields['comment'];
			unset( $fields['comment'] );
			$fields['comment'] = $comment_field;
		}
		return $fields;
	}
	add_filter( 'comment_form_fields', 'vayne_comment_form_fields', 99 );
}

if(!function_exists('vayne_product_comment_form_args')){
	function vayne_product_comment_form_args($args){
		$commenter = wp_get_current_commenter();
		$args['fields'] = array(
			'author' => '<p class="comment-form-author">' .
						'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" required title="' . esc_html_x('Your name', 'front-view', 'vayne') . ' *" placeholder="' . esc_html_x('Your name', 'front-view', 'vayne') . ' *" /></p>',
			'email'  => '<p class="comment-form-email">' .
						'<input id="email" name="email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-required="true" required title="' . esc_html_x('Email', 'front-view', 'vayne') . ' *" placeholder="' . esc_html_x('Email', 'front-view', 'vayne') . ' *" /></p>',
		);
		return $args;
	}
	add_filter('woocommerce_product_review_comment_form_args','vayne_product_comment_form_args');
}